@@ -30,7 +30,7 @@ from twisted.web.server import Request
 from synapse.rest import admin
 from synapse.rest.client import login, media
 from synapse.server import HomeServer
-from synapse.util import Clock
+from synapse.util.clock import Clock
 
 from tests.http import (
     TestServerTLSConnectionFactory,
