@@ -25,7 +25,7 @@ from twisted.web.resource import Resource
 
 from synapse.media._base import FileInfo
 from synapse.server import HomeServer
-from synapse.util import Clock
+from synapse.util.clock import Clock
 
 from tests import unittest
 from tests.test_utils import SMALL_PNG
